/*
   @file    STEVAL_MKBOXPRO_MEMS_6D_Orientation.ino
   @author  STMicroelectronics  
   @brief   Example to use the LSM6DSV16X 6D Orientation
 *******************************************************************************
   Copyright (c) 2022, STMicroelectronics
   All rights reserved.
   This software component is licensed by ST under BSD 3-Clause license,
   the "License"; You may not use this file except in compliance with the
   License. You may obtain a copy of the License at:
                          opensource.org/licenses/BSD-3-Clause
 *******************************************************************************
*/
#include <LSM6DSV16XSensor.h>

// Uncomment if you want to use SPI for LSM6DSV16X
// #define SPI_ENABLE

#ifdef SPI_ENABLE
#define MCU_SEL PI0
#define LIS2DU12_CS PI7
#define LSM6DSV16X_CS PI5
LSM6DSV16XSensor LSM6DSV16X(&SPI, LSM6DSV16X_CS);
#else
LSM6DSV16XSensor LSM6DSV16X(&Wire);
#endif

//Interrupts.
volatile int mems_event = 0;

char report[256];

void INT1Event_cb();
void sendOrientation();

void setup() {

  // Initlialize serial.
  Serial.begin(115200);
  delay(1000);

  // Initlialize Led.
  pinMode(LED_BUILTIN, OUTPUT);

  // Initlialize i2c.
  Wire.begin();

  #ifdef SPI_ENABLE
    // Initlialize spi.
    pinMode(MCU_SEL, OUTPUT);
    digitalWrite(MCU_SEL, LOW);
    SPI.begin();

    pinMode(LSM6DSV16X_CS, OUTPUT);
    digitalWrite(LSM6DSV16X_CS, HIGH);
    
    pinMode(LIS2DU12_CS, OUTPUT);
    digitalWrite(LIS2DU12_CS, HIGH);
  #endif

  // Enable INT1 pin.
  attachInterrupt(PA4, INT1Event_cb, RISING);
    
  // Initlialize components.
  LSM6DSV16X.begin();
  LSM6DSV16X.Enable_X();

  // Enable 6D Orientation.
  LSM6DSV16XStatusTypeDef ret = LSM6DSV16X.Enable_6D_Orientation(LSM6DSV16X_INT1_PIN);
}

void loop() {
  if (mems_event)
  {
    mems_event = 0;
    LSM6DSV16X_Event_Status_t status;
    LSM6DSV16X.Get_X_Event_Status(&status);

    if (status.D6DOrientationStatus)
    {
      // Send 6D Orientation
      sendOrientation();
      
      // Led blinking.
      digitalWrite(LED_BUILTIN, HIGH);
      delay(100);
      digitalWrite(LED_BUILTIN, LOW);
    }
  }
}

void INT1Event_cb()
{
  mems_event = 1;
}

void sendOrientation()
{
  uint8_t xl = 0;
  uint8_t xh = 0;
  uint8_t yl = 0;
  uint8_t yh = 0;
  uint8_t zl = 0;
  uint8_t zh = 0;
  
  LSM6DSV16X.Get_6D_Orientation_XL(&xl);
  LSM6DSV16X.Get_6D_Orientation_XH(&xh);
  LSM6DSV16X.Get_6D_Orientation_YL(&yl);
  LSM6DSV16X.Get_6D_Orientation_YH(&yh);
  LSM6DSV16X.Get_6D_Orientation_ZL(&zl);
  LSM6DSV16X.Get_6D_Orientation_ZH(&zh);
  
  if ( xl == 1 && yl == 0 && zl == 0 && xh == 0 && yh == 0 && zh == 0 )
  {
    sprintf( report, "\r\n  ________________  " \
                      "\r\n |                | " \
                      "\r\n |  *             | " \
                      "\r\n |                | " \
                      "\r\n |                | " \
                      "\r\n |                | " \
                      "\r\n |                | " \
                      "\r\n |________________| \r\n" );
  }
  
  else if ( xl == 0 && yl == 1 && zl == 0 && xh == 0 && yh == 0 && zh == 0 )
  {
    sprintf( report, "\r\n  ________________  " \
                      "\r\n |                | " \
                      "\r\n |             *  | " \
                      "\r\n |                | " \
                      "\r\n |                | " \
                      "\r\n |                | " \
                      "\r\n |                | " \
                      "\r\n |________________| \r\n" );
  }
  
  else if ( xl == 0 && yl == 0 && zl == 0 && xh == 0 && yh == 1 && zh == 0 )
  {
    sprintf( report, "\r\n  ________________  " \
                      "\r\n |                | " \
                      "\r\n |                | " \
                      "\r\n |                | " \
                      "\r\n |                | " \
                      "\r\n |                | " \
                      "\r\n |  *             | " \
                      "\r\n |________________| \r\n" );
  }
  
  else if ( xl == 0 && yl == 0 && zl == 0 && xh == 1 && yh == 0 && zh == 0 )
  {
    sprintf( report, "\r\n  ________________  " \
                      "\r\n |                | " \
                      "\r\n |                | " \
                      "\r\n |                | " \
                      "\r\n |                | " \
                      "\r\n |                | " \
                      "\r\n |             *  | " \
                      "\r\n |________________| \r\n" );
  }
  
  else if ( xl == 0 && yl == 0 && zl == 0 && xh == 0 && yh == 0 && zh == 1 )
  {
    sprintf( report, "\r\n  __*_____________  " \
                      "\r\n |________________| \r\n" );
  }
  
  else if ( xl == 0 && yl == 0 && zl == 1 && xh == 0 && yh == 0 && zh == 0 )
  {
    sprintf( report, "\r\n  ________________  " \
                      "\r\n |________________| " \
                      "\r\n    *               \r\n" );
  }
  
  else
  {
    sprintf( report, "None of the 6D orientation axes is set in accelrometer.\r\n" );
  }
  
  Serial.print(report);
}
